@@ -323,7 +323,8 @@ def symbolic_ref(repo, ref_name, force=False):
         repo_obj.refs.set_symbolic_ref(b'HEAD', ref_path)
 
 
-def commit(repo=".", message=None, author=None, committer=None, encoding=None):
+def commit(repo=".", message=None, author=None, committer=None, encoding=None,
+           no_verify=False):
     """Create a new commit.
 
     Args:
@@ -331,6 +332,7 @@ def commit(repo=".", message=None, author=None, committer=None, encoding=None):
       message: Optional commit message
       author: Optional author name and email
       committer: Optional committer name and email
+      no_verify: Skip pre-commit and commit-msg hooks
     Returns: SHA1 of the new commit
     """
     # FIXME: Support --all argument
@@ -344,7 +346,7 @@ def commit(repo=".", message=None, author=None, committer=None, encoding=None):
     with open_repo_closing(repo) as r:
         return r.do_commit(
                 message=message, author=author, committer=committer,
-                encoding=encoding)
+                encoding=encoding, no_verify=no_verify)
 
 
 def commit_tree(repo, tree, message=None, author=None, committer=None):
@@ -1115,14 +1117,11 @@ def status(repo=".", ignored=False):
         unstaged_changes = list(
             get_unstaged_changes(index, r.path, filter_callback)
         )
-        ignore_manager = IgnoreFilterManager.from_repo(r)
-        untracked_paths = get_untracked_paths(r.path, r.path, index)
-        if ignored:
-            untracked_changes = list(untracked_paths)
-        else:
-            untracked_changes = [
-                    p for p in untracked_paths
-                    if not ignore_manager.is_ignored(p)]
+
+        untracked_paths = get_untracked_paths(r.path, r.path, index,
+                                              exclude_ignored=not ignored)
+        untracked_changes = list(untracked_paths)
+
         return GitStatus(tracked_changes, unstaged_changes, untracked_changes)
 
 
@@ -1152,15 +1151,25 @@ def _walk_working_dir_paths(frompath, basepath):
             yield filepath, False
 
 
-def get_untracked_paths(frompath, basepath, index):
+def get_untracked_paths(frompath, basepath, index, exclude_ignored=False):
     """Get untracked paths.
 
     Args:
-    ;param frompath: Path to walk
+      frompath: Path to walk
       basepath: Path to compare to
       index: Index to check against
+      exclude_ignored: Whether to exclude ignored paths
     """
+    if exclude_ignored:
+        with open_repo_closing(frompath) as r:
+            ignore_manager = IgnoreFilterManager.from_repo(r)
+    else:
+        ignore_manager = None
+
     for ap, is_dir in _walk_working_dir_paths(frompath, basepath):
+        if (ignore_manager is not None and
+                ignore_manager.is_ignored(os.path.relpath(ap, frompath))):
+            continue
         if not is_dir:
             ip = path_to_tree_path(basepath, ap)
             if ip not in index:
